==> localnews-user-service-1.0.3-sources.jar: com/bxm/localnews/user/service/impl/ChannelServiceImpl.java <==
package com.bxm.localnews.user.service.impl;

import java.util.List;
import java.util.Map;

import com.bxm.localnews.user.config.BizConfigProperties;
import com.bxm.localnews.user.constant.RedisConfig;
import com.bxm.localnews.user.domain.ChannelMapper;
import com.bxm.localnews.user.dto.ChannelDTO;
import com.bxm.localnews.user.service.ChannelService;
import com.bxm.localnews.user.vo.Channel;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.fasterxml.jackson.core.type.TypeReference;
import com.github.pagehelper.PageHelper;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

/**
 * Created by Administrator on 2017/12/23.
 */

@Service
@RefreshScope
public class ChannelServiceImpl implements ChannelService {

    private final static Logger logger = LoggerFactory.getLogger(ChannelServiceImpl.class);

    private ChannelMapper channelMapper;

    private BizConfigProperties bizConfigProperties;

    private RedisStringAdapter redisStringAdapter;

    @Autowired
    public ChannelServiceImpl(ChannelMapper channelMapper, BizConfigProperties bizConfigProperties,
                              RedisStringAdapter redisStringAdapter) {
        this.channelMapper = channelMapper;
        this.bizConfigProperties = bizConfigProperties;
        this.redisStringAdapter = redisStringAdapter;
    }

    @Override
    public List<ChannelDTO> listChannel(Map<String, Object> searchMap, int current, int pageSize) {
        PageHelper.startPage(current, pageSize);
        List<ChannelDTO> list = this.channelMapper.selectChannelList(searchMap);
        String channelUrl = bizConfigProperties.getChannelUrl();

        for (ChannelDTO channelDTO : list) {
            channelDTO.setGeneralizeUrl(channelUrl + channelDTO.getCode());
        }

        return list;
    }

    @Override
    public Channel getChannelByCode(String code) {
        Channel channel = new Channel();
        List<Channel> channelList = getChannelList();
        for (Channel ch : channelList) {
            if (ch.getCode().equals(code)) {
                channel = ch;
                break;
            }
        }

        return channel;
    }

    /**
     * 获取所有的渠道列表
     *
     * @return
     */
    private List<Channel> getChannelList() {
        TypeReference<List<Channel>> typeReference = new TypeReference<List<Channel>>() {
        };
        List<Channel> channelList = this.redisStringAdapter.get(this.getChannelListKey(), typeReference);
        if (CollectionUtils.isEmpty(channelList)) {
            channelList = this.channelMapper.getAllChannel();
            this.redisStringAdapter.set(this.getChannelListKey(), channelList);
        }

        return channelList;
    }

    /**
     * 获取渠道版本列表的key
     *
     * @return
     */
    private KeyGenerator getChannelListKey() {
        return RedisConfig.BASE_CHANNEL.copy().appendKey("list");
    }

}

==> localnews-user-service-1.0.8-sources.jar: com/bxm/localnews/user/service/impl/ChannelServiceImpl.java <==
package com.bxm.localnews.user.service.impl;

import java.util.List;
import java.util.Map;

import com.bxm.localnews.user.config.BizConfigProperties;
import com.bxm.localnews.user.constant.RedisConfig;
import com.bxm.localnews.user.domain.ChannelMapper;
import com.bxm.localnews.user.dto.ChannelDTO;
import com.bxm.localnews.user.service.ChannelService;
import com.bxm.localnews.user.vo.Channel;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.fasterxml.jackson.core.type.TypeReference;
import com.github.pagehelper.PageHelper;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

/**
 * Created by Administrator on 2017/12/23.
 */

@Service
@RefreshScope
public class ChannelServiceImpl implements ChannelService {

    private final static Logger logger = LoggerFactory.getLogger(ChannelServiceImpl.class);

    private ChannelMapper channelMapper;

    private BizConfigProperties bizConfigProperties;

    private RedisStringAdapter redisStringAdapter;

    @Autowired
    public ChannelServiceImpl(ChannelMapper channelMapper, BizConfigProperties bizConfigProperties,
                              RedisStringAdapter redisStringAdapter) {
        this.channelMapper = channelMapper;
        this.bizConfigProperties = bizConfigProperties;
        this.redisStringAdapter = redisStringAdapter;
    }

    @Override
    public List<ChannelDTO> listChannel(Map<String, Object> searchMap, int current, int pageSize) {
        PageHelper.startPage(current, pageSize);
        List<ChannelDTO> list = this.channelMapper.selectChannelList(searchMap);
        String channelUrl = bizConfigProperties.getChannelUrl();

        for (ChannelDTO channelDTO : list) {
            channelDTO.setGeneralizeUrl(channelUrl + channelDTO.getCode());
        }

        return list;
    }

    @Override
    public Channel getChannelByCode(String code) {
        Channel channel = new Channel();
        List<Channel> channelList = getChannelList();
        for (Channel ch : channelList) {
            if (ch.getCode().equals(code)) {
                channel = ch;
                break;
            }
        }

        return channel;
    }

    @Override
    public String getChannelCodeById(Long channelId) {
        Channel channel = new Channel();
        List<Channel> channelList = getChannelList();
        for (Channel ch : channelList) {
            if (ch.getId().equals(channelId)) {
                channel = ch;
                break;
            }
        }
        return channel.getCode();
    }

    /**
     * 获取所有的渠道列表
     *
     * @return
     */
    private List<Channel> getChannelList() {
        TypeReference<List<Channel>> typeReference = new TypeReference<List<Channel>>() {
        };
        List<Channel> channelList = this.redisStringAdapter.get(this.getChannelListKey(), typeReference);
        if (CollectionUtils.isEmpty(channelList)) {
            channelList = this.channelMapper.getAllChannel();
            this.redisStringAdapter.set(this.getChannelListKey(), channelList);
        }

        return channelList;
    }

    /**
     * 获取渠道版本列表的key
     *
     * @return
     */
    private KeyGenerator getChannelListKey() {
        return RedisConfig.BASE_CHANNEL.copy().appendKey("list");
    }

}
